package com.jiuqi.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.jar.Attributes;
import java.util.jar.JarFile;
import java.util.jar.Manifest;
import org.eclipse.osgi.util.ManifestElement;

public class ManifestUtil {
   public static final String MANIFEST_FILE_PATH = "/META-INF/MANIFEST.MF";

   public static Manifest getManifest(String path) {
      return getManifest(new File(path));
   }

   public static Manifest getManifest(File file) {
      if (file != null && file.exists()) {
         if (file.isDirectory()) {
            return getManifestFromDir(file);
         } else {
            return file.isFile() ? getManifestFromJar(file) : null;
         }
      } else {
         return null;
      }
   }

   public static Manifest getManifestFromDir(String path) {
      Manifest manifest = null;

      try {
         InputStream in = new FileInputStream(path + "/META-INF/MANIFEST.MF");
         manifest = new Manifest(in);
      } catch (IOException var3) {
         manifest = null;
      }

      return manifest;
   }

   public static Manifest getManifestFromDir(File file) {
      return getManifestFromDir(file.getAbsolutePath());
   }

   public static Manifest getManifestFromJar(String path) {
      return getManifestFromJar(new File(path));
   }

   public static Manifest getManifestFromJar(File file) {
      Manifest manifest = null;

      try {
         JarFile jar = new JarFile(file);
         manifest = jar.getManifest();
      } catch (IOException var3) {
         manifest = null;
      }

      return manifest;
   }

   public static void saveManifest(String path, Manifest manifest) {
      OutputStream out = null;

      try {
         out = new FileOutputStream(path + "/META-INF/MANIFEST.MF");
         manifest.write(out);
         out.close();
      } catch (FileNotFoundException var3) {
      } catch (IOException var4) {
      }

   }

   public static String getAttributeRawValue(Attributes attributes, String attributeName) {
      return attributes.getValue(attributeName);
   }

   public static String getAttributeValue(Attributes attributes, String attributeName) {
      String[] values = getAttributeValues(attributes, attributeName);
      return values.length > 0 ? values[0] : null;
   }

   public static String[] getAttributeValues(Attributes attributes, String attributeName) {
      String rawValue = getAttributeRawValue(attributes, attributeName);
      if (rawValue == null) {
         return new String[0];
      } else {
         String[] values = (String[])null;

         try {
            ManifestElement[] elements = ManifestElement.parseHeader(attributeName, rawValue);
            values = new String[elements.length];

            for(int i = 0; i < elements.length; ++i) {
               values[i] = elements[i].getValue();
            }
         } catch (Exception var6) {
            Exception e = var6;
            e.printStackTrace();
         }

         if (values == null) {
            values = new String[0];
         }

         return values;
      }
   }
}
